@@ -456,7 +456,9 @@ int DoOmit(ParsePtr p)
                 InsertIntoSortedArray(PartialOmitArray, NumPartialOmits, syndrome);
                 NumPartialOmits++;
                 if (NumPartialOmits == 366) {
-                    Wprint(tr("You have OMITted everything!  The space-time continuum is at risk."));
+                    if (warning_level("04.02.09")) {
+                        Wprint(tr("You have OMITted everything!  The space-time continuum is at risk."));
+                    }
                 }
             }
             if (mc == m[1] && dc == d[1]) {
@@ -512,6 +514,14 @@ DumpOmits(void)
 {
     int i;
     int y, m, d;
+
+    /* Do nothing in --json mode */
+    if (JSONMode) {
+        return;
+    }
+    if (PurgeMode) {
+        return;
+    }
     printf("Global Full OMITs (%d of maximum allowed %d):\n", NumFullOmits, MAX_FULL_OMITS);
     if (!NumFullOmits) {
         printf("\tNone.\n");
